
# Slot: symbol


Symbol for a particular thing

URI: [biolink:symbol](https://w3id.org/biolink/vocab/symbol)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [Gene](Gene.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | alliancegenome:symbol |
|  | | gpi:DB_Object_Symbol |

